#!/bin/bash
#
# ssh-api:ssh-api.sh
#
if [ "$( type -t _ssh_api_do_ssh )" != 'function' ] ; then
  # shellcheck disable=SC1091
  source "$( dirname "${BASH_SOURCE[0]}" )/ssh-common-api.sh" || exit $?
fi

function ssh_api_do_ssh {
  local -r _ssh_user_="$1"
  local -r _ssh_host_="$2"
  local -r _ssh_cmd_="$3"

  _ssh_api_do_ssh "${_ssh_user_}" "${_ssh_host_}" "${_ssh_cmd_}" || return $?
}

function ssh_api_update_known_hosts {
  local -r host="$1"
  local -r key_type="${2:-}" # default ecdsa

  # Fix bad known_hosts files
  sed -i '/^null$/d' ~/.ssh/known_hosts || return $?

  local -a ssh_keyscan_params=()
  case "${key_type}" in
    '')
      echowarn "${FUNCNAME[0]}( '${host}' '${key_type}' ) - No type"
      ssh_keyscan_params+=(-t ecdsa) # Key ECDSA
      ;;

    'all')
      ssh_keyscan_params+=(-H) # All keys
      ;;

    'ecdsa'|'rsa')
      ssh_keyscan_params+=("${key_type}")
      ;;

    *)
      echowarn "${FUNCNAME[0]}( '${host}' '${key_type}' ) - Strange type"
      ssh_keyscan_params+=("${key_type}")
      ;;
  esac

  while ssh-keygen -f ~/.ssh/known_hosts -H -F "${host}" >/dev/null ; do
    ssh-keygen -f ~/.ssh/known_hosts -R "${host}"
  done
  result="$( ssh-keyscan "${ssh_keyscan_params[@]}" "${host}" )" || return $?
  echo "${result}" >> ~/.ssh/known_hosts
}
